
package framemax;

import java.awt.*;

/**
 *
 * @author Yvonne V. Richardson Graphic Array Handling Lecture
 *
 * Each shape that can be drawn is contained in its own class. The drawing 
 * methods for the shape are contained in the class, but the GridPanel extension 
 * of the JPanel class contains the paintComponent method that calls the
 * methods within the shape.
 */
public class Line {
  // Each object to be drawn is prescribed in its own class
  // The JVM automatically triggers the paintComponent to
  // draw the shape in response to certain events

  private int originX, originY, endpointX, endpointY;
  private Color color;  // lines have no fill color

  // constructors
  public Line() {
    originX = 0;
    originY = 0;
    endpointX = 0;
    endpointY = 0;
    
    color = Color.WHITE;
  }
  
  public Line(int x1, int y1, int x2, int y2, Color c) {
    originX = x1;
    originY = y1;
    endpointX = x2;
    endpointY = y2;
    
    color = c;
  }

  // accessors for private instance variables
  public int originX() {
    // returns the x coordinate of the originating endpoint 
    return originX;
  }
  
  public int getOriginX() {
    // returns the x coordinate of the originating endpoint 
    return originX;
  }

  public int originY() {
    // returns the y coordinate of the originating endpoint 
    return originY;
  }
public int getOriginY() {
    // returns the y coordinate of the originating endpoint 
    return originY;
  }

  public int endpointX() {
    // returns the x coordinate of the terminating endpoint 
    return endpointX;
  }
  
  public int getEndpointX() {
    // returns the x coordinate of the terminating endpoint 
    return endpointX;
  }

  public int endpointY() {
    // returns the y coordinate of the terminating endpoint 
    return endpointY;
  }
public int getEndpointY() {
    // returns the y coordinate of the terminating endpoint 
    return endpointY;
  }

  public Color color() {
    // returns the color object
    return color;
  }

  public Color getColor() {
    // returns the color object
    return color;
  }

    // mutators for private instance variables
  public void setOriginX(int x1) {
    // sets the x coordinate of the originating endpoint
    originX = x1;
  }

  public void setOriginY(int y1) {
    // sets the y coordinate of the originating endpoint
    originY = y1;
  }

  public void setEndpointX(int x2) {
    // sets the x coordinate of the terminating endpoint
    endpointX = x2;
  }

  public void setEndpointY(int y2) {
    // sets the y coordinate of the terminating endpoint
    endpointY = y2;
  }

  public Color setColor(Color c) {
    // sets the color object
    color = c;
    return color;
  }

// overrides from inherited classes
  public String toString() {
    String objHelp = "origin is (" + Integer.toString(originX) + ", "
     + Integer.toString(originY) + "), endpoint is ("
     + Integer.toString(endpointX) + ", " + Integer.toString(endpointY) + "), "
     + "color is " + color.toString();
    return objHelp;
  }

  public void draw(Graphics g) {
    // Save the current color of the graphics context
    //   and set color to the color of the line
    Color oldColor = g.getColor();
    g.setColor(color);
    // Draw the line 
    g.drawLine(originX, originX, endpointX, endpointX);
   // Restore the color of the graphics context
   
    g.setColor(oldColor);
  }

  public void move(int xAmount, int yAmount) {
    originX = originX + xAmount;
    originY = originY + yAmount;

  }
} // class Line
